aboutsummaryrefslogtreecommitdiff
path: root/keyboards/hineybush/physix
diff options
context:
space:
mode:
authorRyan <[email protected]>2024-05-03 15:21:29 +1000
committerGitHub <[email protected]>2024-05-03 15:21:29 +1000
commitd09a06a1b354760fd0e64a453abade972900e885 (patch)
tree88d94640f4507ac8d7f570607423825bec3c6f89 /keyboards/hineybush/physix
parent5426a7a129acf2ff5c8b435014747f1238e17965 (diff)
downloadqmk_firmware-d09a06a1b354760fd0e64a453abade972900e885.tar.gz
qmk_firmware-d09a06a1b354760fd0e64a453abade972900e885.zip
Update GPIO API usage in keyboard code (#23361)
Diffstat (limited to 'keyboards/hineybush/physix')
-rw-r--r--keyboards/hineybush/physix/physix.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/keyboards/hineybush/physix/physix.c b/keyboards/hineybush/physix/physix.c
index c118b30d2e..cd920a72b3 100644
--- a/keyboards/hineybush/physix/physix.c
+++ b/keyboards/hineybush/physix/physix.c
@@ -24,8 +24,8 @@
void matrix_init_kb(void) {
// put your keyboard start-up code here
// runs once when the firmware starts up
- setPinOutput(D3);
- setPinOutput(D5);
+ gpio_set_pin_output(D3);
+ gpio_set_pin_output(D5);
matrix_init_user();
}
@@ -33,13 +33,13 @@ bool led_update_kb(led_t led_state) {
// put your keyboard LED indicator (ex: Caps Lock LED) toggling code here
bool res = led_update_user(led_state);
if(res) {
// writePin sets the pin high for 1 and low for 0.
// In this example the pins are inverted, setting
// it low/0 turns it on, and high/1 turns the LED off.
// This behavior depends on whether the LED is between the pin
// and VCC or the pin and GND.
- writePin(D3, led_state.caps_lock);
- writePin(D5, led_state.scroll_lock);
+ gpio_write_pin(D3, led_state.caps_lock);
+ gpio_write_pin(D5, led_state.scroll_lock);
}
return res;
return led_update_user(led_state);
@@ -33,13 +33,13 @@ bool led_update_kb(led_t led_state) {
bool res = led_update_user(led_state);
if(res) {
- // writePin sets the pin high for 1 and low for 0.
+ // gpio_write_pin sets the pin high for 1 and low for 0.
// In this example the pins are inverted, setting
// it low/0 turns it on, and high/1 turns the LED off.